package com.ruoyi.nanjing.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.Ztree;
import com.ruoyi.nanjing.domain.TBdSubstation;
import com.ruoyi.system.domain.SysDept;

/**
 * 工位管理Service接口
 * 
 * @author limy
 * @date 2021-01-22
 */
public interface ITBdSubstationService 
{
    /**
     * 查询工位管理
     * 
     * @param ID 工位管理ID
     * @return 工位管理
     */
    public TBdSubstation selectTBdSubstationById(Long ID);

    /**
     * 查询工位管理列表
     * 
     * @param tBdSubstation 工位管理
     * @return 工位管理集合
     */
    public List<TBdSubstation> selectTBdSubstationList(TBdSubstation tBdSubstation);

    /**
     * 新增工位管理
     * 
     * @param tBdSubstation 工位管理
     * @return 结果
     */
    public int insertTBdSubstation(TBdSubstation tBdSubstation);

    /**
     * 修改工位管理
     * 
     * @param tBdSubstation 工位管理
     * @return 结果
     */
    public int updateTBdSubstation(TBdSubstation tBdSubstation);

    /**
     * 批量删除工位管理
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTBdSubstationByIds(String ids);

    /**
     * 删除工位管理信息
     * 
     * @param ID 工位管理ID
     * @return 结果
     */
    public int deleteTBdSubstationById(Long ID);

    List<TBdSubstation> selectStationcode();

    List<TBdSubstation> selectOrderid();

    String createTable(Map map);

    void updateTable(Map map);

    void deletePara(Map map);

    List<Ztree> selectTbdStationTree(TBdSubstation substation);
}
